@@ -79,7 +79,7 @@ class BaseStrategy(object):
             'sync' if self.sync else 'async',
             'no real DSA' if self.no_real_dsa else 'real DSA',
             'pooled' if self.pooled else 'not pooled',
-            'can stream output' if self.pooled else 'cannot stream output',
+            'can stream output' if self.can_stream else 'cannot stream output',
         ]
         return ' - '.join(s)
 
@@ -633,6 +633,10 @@ class BaseStrategy(object):
             referral_server = Server(host=selected_referral['host'],
                                      port=selected_referral['port'] or self.connection.server.port,
                                      use_ssl=selected_referral['ssl'],
+                                     get_info=self.connection.server.get_info,
+                                     formatter=self.connection.server.custom_formatter,
+                                     connect_timeout=self.connection.server.connect_timeout,
+                                     mode=self.connection.server.mode,
                                      allowed_referral_hosts=self.connection.server.allowed_referral_hosts,
                                      tls=Tls(local_private_key_file=self.connection.server.tls.private_key_file,
                                              local_certificate_file=self.connection.server.tls.certificate_file,
