@@ -82,21 +82,21 @@ class CaseInsensitiveDict(collections.MutableMapping):
     def values(self):
         return self._store.values()
 
+    def items(self):
+        return self._store.items()
+
     def __eq__(self, other):
         if not isinstance(other, (collections.Mapping, dict)):
             return NotImplemented
 
         if isinstance(other, CaseInsensitiveDict):
-            if isinstance(self.items(), SEQUENCE_TYPES):  # python 2
-                if len(self.items()) != len(other.items()):
-                    return False
-                else:
-                    for key, value in self.items():
-                        if not (key in other and other[key] == value):
-                            return False
-                    return True
+            if len(self.items()) != len(other.items()):
+                return False
             else:
-                return self.items() == other.items()
+                for key, value in self.items():
+                    if not (key in other and other[key] == value):
+                        return False
+                return True
 
         return self == CaseInsensitiveDict(other)
 
