@@ -31,6 +31,15 @@ from ..utils.ciDict import CaseInsensitiveDict
 from ..core.exceptions import LDAPDefinitionError
 
 
+def escape_filter_chars(text):
+    """ Escape chars mentioned in RFC4515. """
+    output = text.replace('\\', r'\5c')
+    output = output.replace(r'*', r'\2a')
+    output = output.replace(r'(', r'\28')
+    output = output.replace(r')', r'\29')
+    output = output.replace('\x00', r'\00')
+    return output
+
 def escape_bytes(bytes_value):
     if bytes_value:
         if str != bytes:  # Python 3
@@ -82,6 +91,7 @@ def json_encode_b64(obj):
         raise LDAPDefinitionError('unable to encode ' + str(obj) + ' - ' + str(e))
 
 
+# noinspection PyProtectedMember
 def check_json_dict(json_dict):
     # needed for python 2
 
@@ -103,12 +113,13 @@ def check_json_dict(json_dict):
 
 
 def json_hook(obj):
-    if hasattr(obj, 'keys') and len(obj.keys()) == 2 and 'encoding' in obj.keys() and 'encoded' in obj.keys():
+    if hasattr(obj, 'keys') and len(list(obj.keys())) == 2 and 'encoding' in obj.keys() and 'encoded' in obj.keys():
         return b64decode(obj['encoded'])
 
     return obj
 
 
+# noinspection PyProtectedMember
 def format_json(obj):
     if isinstance(obj, CaseInsensitiveDict):
         return obj._store
