@@ -21,7 +21,9 @@
 # If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
+from time import sleep
 
+from ldap3.protocol.microsoft import extended_dn_control, show_deleted_control, dir_sync_control
 from ldap3.utils.conv import escape_bytes
 from test import test_base, test_name_attr, random_id, get_connection, \
     add_user, drop_connection, test_server_type, test_int_attr
@@ -57,7 +59,10 @@ class Test(unittest.TestCase):
             result = self.connection.result
         self.assertEqual(result['description'], 'success')
         self.assertEqual(len(response), 1)
-        self.assertEqual(response[0]['attributes']['givenName'][0], 'givenname-1')
+        if test_server_type == 'AD':
+            self.assertEqual(response[0]['attributes']['givenName'], 'givenname-1')
+        else:
+            self.assertEqual(response[0]['attributes']['givenName'][0], 'givenname-1')
 
     def test_search_extensible_match(self):
         if test_server_type == 'EDIR':
@@ -99,7 +104,10 @@ class Test(unittest.TestCase):
             result = self.connection.result
         self.assertEqual(result['description'], 'success')
         if self.connection.check_names:
-            self.assertEqual(response[0]['attributes']['entryDN'][0], self.delete_at_teardown[0][0])
+            if test_server_type == 'AD':
+                self.assertEqual(response[0]['dn'].lower(), self.delete_at_teardown[0][0].lower())
+            else:
+                self.assertEqual(response[0]['attributes']['entryDN'], self.delete_at_teardown[0][0])
 
     def test_search_simple_paged(self):
         if not self.connection.strategy.pooled:
@@ -146,7 +154,10 @@ class Test(unittest.TestCase):
             result = self.connection.result
         self.assertEqual(result['description'], 'success')
         self.assertEqual(len(response), 1)
-        self.assertEqual(response[0]['attributes'][test_name_attr][0], testcase_id + '(search)-10')
+        if test_server_type == 'AD':
+            self.assertEqual(response[0]['attributes'][test_name_attr], testcase_id + '(search)-10')
+        else:
+            self.assertEqual(response[0]['attributes'][test_name_attr][0], testcase_id + '(search)-10')
 
     def test_search_integer_exact_match(self):
         result = self.connection.search(search_base=test_base, search_filter='(&(' + test_name_attr + '=' + testcase_id + '*)(' + test_int_attr + '=0))', attributes=[test_name_attr, test_int_attr])
@@ -185,7 +196,7 @@ class Test(unittest.TestCase):
         if not self.connection.strategy.sync:
             response, result = self.connection.get_response(result)
         else:
-            response = [entry for entry in self.connection.response if entry['dn'].startswith(test_name_attr + '=' + testcase_id)]
+            response = [entry for entry in self.connection.response if entry['dn'].lower().startswith(test_name_attr.lower() + '=' + testcase_id.lower())]
             result = self.connection.result
         self.assertEqual(result['description'], 'success')
         self.assertTrue(len(response) >= 1)
